@@ -18,6 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import os
+import optparse
 import re
 import stat
 import sys
@@ -126,6 +127,9 @@ class cmd_cleanone(Command):
             make_option('--honour-config',
                         action='store_true', dest='honour_config', default=False,
                         help=_('honour the makeclean setting in config file')),
+            make_option('--distclean',
+                        action='store_true', dest='distclean', default=False,
+                        help=_('completely clean source tree')),
             ])
 
     def run(self, config, options, args, help=None):
@@ -146,7 +150,11 @@ class cmd_cleanone(Command):
             return 0
 
         build = jhbuild.frontends.get_buildscript(config, module_list, module_set=module_set)
-        return build.build(phases=['clean'])
+        if options.distclean:
+            clean_phase = 'distclean'
+        else:
+            clean_phase = 'clean'
+        return build.build(phases=[clean_phase])
 
 register_command(cmd_cleanone)
 
@@ -161,7 +169,10 @@ class cmd_build(BuildCommand):
         Command.__init__(self, [
             make_option('-a', '--autogen',
                         action='store_true', dest='_unused', default=False,
-                        help=_('This option does nothing anymore')),
+                        help=optparse.SUPPRESS_HELP), # no longer used
+            make_option('', '--distclean',
+                        action='store_true', dest='distclean', default=False,
+                        help=_('completely clean source tree')),
             make_option('-c', '--clean',
                         action='store_true', dest='clean', default=False,
                         help=_('run make clean before make')),
@@ -242,16 +253,16 @@ class cmd_build(BuildCommand):
                     _('requested module is in the ignore list, nothing to do.'))
             return 0
 
-        module_state = module_set.get_system_modules(full_module_list)
-        if (config.check_sysdeps
-            and not self.required_system_dependencies_installed(module_state)):
-            self.print_system_dependencies(module_state)
-            raise FatalError(_('Required system dependencies not installed. '
-                               'Install using the command %(cmd)s or to '
-                               'ignore system dependencies use command-line '
-                               'option %(opt)s' \
-                               % {'cmd' : "'jhbuild sysdeps --install'",
-                                  'opt' : '--nodeps'}))
+        if config.check_sysdeps:
+            module_state = module_set.get_system_modules(full_module_list)
+            if not self.required_system_dependencies_installed(module_state):
+                self.print_system_dependencies(module_state)
+                raise FatalError(_('Required system dependencies not installed.'
+                                   ' Install using the command %(cmd)s or to '
+                                   'ignore system dependencies use command-line'
+                                   ' option %(opt)s' \
+                                   % {'cmd' : "'jhbuild sysdeps --install'",
+                                      'opt' : '--nodeps'}))
 
         build = jhbuild.frontends.get_buildscript(config, module_list, module_set=module_set)
         return build.build()
@@ -269,10 +280,13 @@ class cmd_buildone(BuildCommand):
         Command.__init__(self, [
             make_option('-a', '--autogen',
                         action='store_true', dest='_unused', default=False,
-                        help=_('This option does nothing anymore')),
+                        help=optparse.SUPPRESS_HELP), # no longer used
             make_option('-c', '--clean',
                         action='store_true', dest='clean', default=False,
                         help=_('run make clean before make')),
+            make_option('', '--distclean',
+                        action='store_true', dest='distclean', default=False,
+                        help=_('completely clean source tree')),
             make_option('--check',
                         action='store_true', dest='check', default=False,
                         help=_('run make check after building')),
