@@ -63,6 +63,9 @@ class cmd_make(Command):
 
         makeargs = config.makeargs
         for arg in args:
+            # if uninstalling, skip install.
+            if arg == 'uninstall' or arg.startswith('uninstall-'):
+                config.noinstall = True
             # pipes.quote (and really, trying to safely quote shell arguments) is
             # broken, but executing commands as strings is pervasive throughout
             # jhbuild...this is a hack that will probably live until someone just
@@ -78,13 +81,20 @@ class cmd_make(Command):
 
         cwd = cwd[len(config.checkoutroot):]
         cwd = cwd.lstrip(os.sep)
-        name, _slash, _rest = cwd.partition(os.sep)
+        modname, _slash, _rest = cwd.partition(os.sep)
 
         try:
-            module = module_set.get_module(name, ignore_case=True)
+            module = module_set.get_module(modname, ignore_case=True)
         except KeyError, e:
-            logging.error(_('No module matching current directory %r in the moduleset') % (name, ))
-            return False
+            default_repo = jhbuild.moduleset.get_default_repo()
+            if not default_repo:
+                logging.error(_('No module matching current directory %r in the moduleset') % (modname, ))
+                return False
+            from jhbuild.modtypes.autotools import AutogenModule
+            module = AutogenModule(modname, default_repo.branch(modname))
+            module.config = config
+            logging.info(_('module "%(modname)s" does not exist, created automatically using repository "%(reponame)s"') % \
+                         {'modname': modname, 'reponame': default_repo.name})
 
         build = jhbuild.frontends.get_buildscript(config, [module], module_set=module_set)
         return build.build()
